@@ -419,7 +419,8 @@ async def django_instance_to_redis_params(
             django_field_name = django_field.name
             allowed = True
             if exclude_fields:
-                allowed = (django_field.name in exclude_fields)
+                allowed = (django_field.name not in exclude_fields)
+                print(allowed, django_field.name)
             if allowed:
                 if django_field.name not in ['id', 'pk']:
                     redis_param = await django_instance_field_to_redis_value(
