@@ -451,7 +451,7 @@ class RedisRoot:
 
     def get_cache_conf(self, django_model):
         if django_model in self.registered_django_models.keys():
-            cache_conf = self.registered_django_models[django_model]
+            cache_conf = self.registered_django_models[django_model]['cache_conf']
             return cache_conf
         else:
             raise Exception(f'{django_model} is not registered')
@@ -463,9 +463,9 @@ class RedisRoot:
             for django_field in django_model._meta.get_fields():
                 django_field_name = django_field.name
                 allowed = True
+                print(exclude_fields)
                 if exclude_fields:
                     allowed = (django_field.name not in exclude_fields)
-                    print(allowed, django_field.name)
                 if allowed:
                     if django_field.name in ['id', 'pk']:
                         django_field_name = 'django_id'
@@ -568,7 +568,7 @@ class RedisRoot:
             redis_root.registered_models = new_registered_models
             return new_redis_model
 
-        cache_conf = self.check_cache_conf(django_model)
+        cache_conf = self.get_cache_conf(django_model)
         save_related_models = cache_conf['save_related_models']
         exclude_fields = cache_conf['exclude_fields']
 
